==> apache-camel-quarkus-2.7.1-src.zip: camel-quarkus-2.7.1/extensions-core/core/runtime/src/main/java/org/apache/camel/quarkus/core/events/ComponentEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.core.events;

import org.apache.camel.CamelContext;
import org.apache.camel.Component;
import org.apache.camel.spi.CamelEvent;

/**
 * Base {@link CamelEvent} for {@link Component} related events.
 */
public class ComponentEvent implements CamelEvent.CamelContextEvent {
    private final Component component;

    public ComponentEvent(Component component) {
        this.component = component;
    }

    @Override
    public CamelContext getContext() {
        return this.component.getCamelContext();
    }

    public Component getComponent() {
        return this.component;
    }

    public <T extends Component> T getComponent(Class<T> type) {
        return type.cast(this.component);
    }

    @Override
    public Type getType() {
        return Type.Custom;
    }
}

==> apache-camel-quarkus-3.30.0-src.zip: camel-quarkus-3.30.0/extensions-core/core/runtime/src/main/java/org/apache/camel/quarkus/core/events/ComponentEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.core.events;

import org.apache.camel.Component;
import org.apache.camel.impl.event.AbstractContextEvent;
import org.apache.camel.spi.CamelEvent;

/**
 * Base {@link CamelEvent} for {@link Component} related events.
 */
public class ComponentEvent extends AbstractContextEvent {
    private final Component component;

    public ComponentEvent(Component component) {
        super(component.getCamelContext());
        this.component = component;
    }

    public Component getComponent() {
        return this.component;
    }

    public <T extends Component> T getComponent(Class<T> type) {
        return type.cast(this.component);
    }

    @Override
    public Type getType() {
        return Type.Custom;
    }
}
